Test coverage report: myapp.models

# myapp.models: 3 total statements, 100.0% covered

Generated: Thu 2012-06-07 23:06 SGT

Source file: /Users/martin/Projects/pycon-apac-2012/tdd-with-django/reusable-app/myapp/models.py

Stats: 2 executed, 0 missed, 1 excluded, 4 ignored

1. `"""Models for appname application."""`
2. `from django.db import models`
3. ``
4. ``
5. `class Example(models.Model):`
6. `"""Example model class."""`
7. `text = models.TextField(blank=True, null=True)`